package server

import (
	"context"
	"encoding/json"
	"fmt"

	"git.loafle.net/commons_go/logging"
	"git.loafle.net/overflow/overflow_gateway_probe/grpc"
	ogw "git.loafle.net/overflow/overflow_gateway_websocket"
	"github.com/valyala/fasthttp"
)

func newMetricServlet() Servlet {
	s := &metricServlet{}
	return s
}

type metricServlet struct {
}

func (s *metricServlet) IsCanConnect(ctx *fasthttp.RequestCtx) bool {
	var buf []byte
	if buf = ctx.Request.Header.Peek(ProbeHeader_ProbeKey); nil != buf {
		return false
	}
	probeKey := string(buf)

	var err error
	gctx := context.Background()
	params := []string{probeKey}

	var result string
	if result, err = grpc.Exec(gctx, "ProbeService.readByProbeKey", params); nil != err {
		logging.Logger.Warn(fmt.Sprintf("Probe: Invalid connect ProbeKey[%s] ip[%s]", probeKey, ctx.RemoteAddr().String()))
		return false
	}
	var probe Probe
	if err = json.Unmarshal([]byte(result), &probe); nil != err {
		logging.Logger.Warn(fmt.Sprintf("Probe: Cannot conver json[%s] ip[%s]", result, ctx.RemoteAddr().String()))
		return false
	}

	return true
}

func (s *metricServlet) SessionUID(soc ogw.Socket) string {

	return ""
}
