package server

import (
	"context"
	"encoding/json"
	"fmt"

	"git.loafle.net/commons_go/logging"
	"git.loafle.net/overflow/overflow_gateway_probe/grpc"
	ogw "git.loafle.net/overflow/overflow_gateway_websocket"
	"github.com/valyala/fasthttp"
)

const (
	ProbeHeader_ProbeKey            = "overFlow-Probe-Key"
	ProbeHeader_Probe_EncryptionKey = "overFlow-Probe-EncryptionKey"
)

func newProbeServlet() Servlet {
	s := &probeServlet{}
	return s
}

type probeServlet struct {
}

func (s *probeServlet) IsCanConnect(ctx *fasthttp.RequestCtx) bool {
	var buf []byte
	if buf = ctx.Request.Header.Peek(ProbeHeader_ProbeKey); nil == buf {
		return false
	}
	probeKey := string(buf)

	var err error
	gctx := context.Background()
	params := []string{probeKey}

	var result string
	if result, err = grpc.Exec(gctx, "ProbeService.readByProbeKey", params); nil != err {
		logging.Logger.Warn(fmt.Sprintf("Probe: Invalid connect ProbeKey[%s] ip[%s]", probeKey, ctx.RemoteAddr().String()))
		return false
	}
	var probe Probe
	if err = json.Unmarshal([]byte(result), &probe); nil != err {
		logging.Logger.Warn(fmt.Sprintf("Probe: Cannot conver json[%s] ip[%s]", result, ctx.RemoteAddr().String()))
		return false
	}

	ctx.Response.Header.Set(ProbeHeader_Probe_EncryptionKey, probe.EncryptionKey)

	return true
}

func (s *probeServlet) SessionUID(soc ogw.Socket) string {
	var buf []byte
	if buf = soc.Conn().Headers().Peek(ProbeHeader_ProbeKey); nil != buf {
		return string(buf)
	}

	return ""
}

type Probe struct {
	ID            uint64 `json:"id"`
	Description   string `json:"description"`
	ProbeKey      string `json:"probeKey"`
	EncryptionKey string `json:"encryptionKey"`
}
